EventBuilderHB

Struct EventBuilderHB 

pub struct EventBuilderHB {
Show 42 fields pub version: ProtocolVersion, pub met_seconds: u64, pub n_mte_received_tot: u32, pub n_rbe_received_tot: u32, pub n_rbe_per_te: u32, pub n_rbe_discarded_tot: u32, pub n_mte_skipped: u32, pub n_timed_out: u32, pub n_timed_out_combo: u32, pub n_sent: u32, pub delta_mte_rbe: u32, pub event_cache_size: u32, pub event_id_cache_size: u32, pub drs_bsy_lost_hg_hits: u32, pub rbe_wo_mte: u32, pub mte_receiver_cbc_len: u32, pub rbe_receiver_cbc_len: u32, pub tp_sender_cbc_len: u32, pub n_rbe_from_past: u32, pub n_rbe_orphan: u32, pub n_rbe_per_loop: u32, pub data_mangled_ev: u32, pub timestamp: u64, pub n_sent_trigger: u32, pub n_sent_combo_trigger: u32, pub reserved_3: u32, pub reserved_4: u32, pub reserved_5: u32, pub reserved_6: u32, pub reserved_7: u32, pub reserved_8: u32, pub reserved_9: u32, pub reserved_10: u32, pub reserved_11: u32, pub reserved_12: u32, pub reserved_13: u32, pub reserved_14: u32, pub reserved_15: u32, pub reserved_16: u32, pub reserved_17: u32, pub reserved_18: u32, pub reserved_19: u32,
}

Fields

version: ProtocolVersionmet_seconds: u64

Mission elapsed time in seconds

n_mte_received_tot: u32

Total number of received MasterTriggerEvents (from MTB)

n_rbe_received_tot: u32

Total number of received RBEvents (from all RB)

n_rbe_per_te: u32

Average number of RBEvents per each MTEvent

n_rbe_discarded_tot: u32

Total number of discarded RBEvents (accross all boards)

n_mte_skipped: u32

TOtal number of missed MTEvents. “Skipped means” gaps in consecutive rising event ids

n_timed_out: u32

Total number of events that timed out, which means they got send before all RBEvents could be associated with this event

n_timed_out_combo: u32

Total number of events that timed out for the secondary trigger, similar as n_timed out

n_sent: u32

Total number of events passed on to the gloabl data sink thread

delta_mte_rbe: u32

?

event_cache_size: u32

The total size of the current event cache in number of events

event_id_cache_size: u32

In paralel to the event_cache, the event_id cache holds event ids. This should be perfectly aligned to the event_cache by design.

drs_bsy_lost_hg_hits: u32

The total number of hits which we lost due to the DRS being busy (this is on the Readoutboards)

rbe_wo_mte: u32

The total number of RBEvents which do not have a MasterTriggerEvent

mte_receiver_cbc_len: u32

The current length of the channel which we use to send events from the MasterTrigger thread to the event builder

rbe_receiver_cbc_len: u32

The current length of the channel whcih we use for all readoutboard threads to send their events to the event builder

tp_sender_cbc_len: u32

the current length of the channel which we use to send built events to the global data sink thread

n_rbe_from_past: u32

The total number of RBEvents which have an event id which is SMALLER than the smallest event id in the event cache.

n_rbe_orphan: u32n_rbe_per_loop: u32data_mangled_ev: u32

The totabl number of events with the “AnyDataMangling” flag set

timestamp: u64n_sent_trigger: u32n_sent_combo_trigger: u32reserved_3: u32reserved_4: u32reserved_5: u32reserved_6: u32reserved_7: u32reserved_8: u32reserved_9: u32reserved_10: u32reserved_11: u32reserved_12: u32reserved_13: u32reserved_14: u32reserved_15: u32reserved_16: u32reserved_17: u32reserved_18: u32reserved_19: u32

Implementations

Source

impl EventBuilderHB

pub fn new() -> Self

pub fn get_average_rbe_te(&self) -> f64

The average number of RBEvents per TofEvent, tis is the average number of active ReadoutBoards per TofEvent

pub fn get_timed_out_frac(&self) -> f64

pub fn get_timed_out_combo_frac(&self) -> f64

pub fn get_timed_out_trigger_frac(&self) -> f64

pub fn get_incoming_vs_outgoing_mte(&self) -> f64

pub fn get_nrbe_discarded_frac(&self) -> f64

pub fn get_mangled_frac(&self) -> f64

pub fn get_drs_lost_frac(&self) -> f64

pub fn pretty_print(&self) -> String